`IRT.parm` <-
function (object, ...) {
    UseMethod("IRT.parm")
}

